@@ -1,4 +1,4 @@
-;;; doric-cherry-theme.el --- Minimalist light theme -*- lexical-binding:t -*-
+;;; doric-cherry-theme.el --- Minimalist theme with light background and pink+purple hues -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2025  Free Software Foundation, Inc.
 
@@ -66,15 +66,15 @@
       (fg-magenta "#800060")
       (fg-cyan "#005560")
 
-      (bg-red "#ffc0c5")
-      (bg-green "#bfefd0")
+      (bg-red "#f2c0c5")
+      (bg-green "#b9e2d0")
       (bg-yellow "#e9e6b0")
       (bg-blue "#bbcce8")
       (bg-magenta "#e0c0e7")
       (bg-cyan "#c2ebe8"))
   "Palette of `doric-cherry' theme.")
 
-  (doric-themes-define-theme doric-cherry light))
+  (doric-themes-define-theme doric-cherry light "Minimalist theme with light background and pink+purple hues"))
 
 (provide 'doric-cherry-theme)
 ;;; doric-cherry-theme.el ends here
