@@ -1,4 +1,4 @@
-;;; doric-plum-theme.el --- Minimalist dark theme -*- lexical-binding:t -*-
+;;; doric-plum-theme.el --- Minimalist theme with dark background and pink+purple hues -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2025  Free Software Foundation, Inc.
 
@@ -66,15 +66,15 @@
       (fg-magenta "#e9acbf")
       (fg-cyan "#a0c0d0")
 
-      (bg-red "#621f33")
-      (bg-green "#19402f")
+      (bg-red "#602038")
+      (bg-green "#124438")
       (bg-yellow "#50442f")
       (bg-blue "#3a386b")
       (bg-magenta "#5a2f40")
       (bg-cyan "#2f495f"))
   "Palette of `doric-plum' theme.")
 
-  (doric-themes-define-theme doric-plum dark))
+  (doric-themes-define-theme doric-plum dark "Minimalist theme with dark background and pink+purple hues"))
 
 (provide 'doric-plum-theme)
 ;;; doric-plum-theme.el ends here
